package com.ruoyi.project.business.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.project.business.domain.TpAreaBasicPrice;
import com.ruoyi.project.business.mapper.TpAreaBasicPriceMapper;
import com.ruoyi.project.business.service.ITpAreaBasicPriceService;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2024-05-20
 */
@Service
public class TpAreaBasicPriceServiceImpl extends ServiceImpl<TpAreaBasicPriceMapper, TpAreaBasicPrice> implements
    ITpAreaBasicPriceService {

    @Resource
    private TpAreaBasicPriceMapper tpAreaBasicPriceMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public TpAreaBasicPrice selectTpAreaBasicPriceById(Long id) {
        return tpAreaBasicPriceMapper.selectTpAreaBasicPriceById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tpAreaBasicPrice 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<TpAreaBasicPrice> selectTpAreaBasicPriceList(TpAreaBasicPrice tpAreaBasicPrice) {
        return tpAreaBasicPriceMapper.selectTpAreaBasicPriceList(tpAreaBasicPrice);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param tpAreaBasicPrice 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTpAreaBasicPrice(TpAreaBasicPrice tpAreaBasicPrice) {
        tpAreaBasicPrice.setCreateTime(DateUtils.getNowDate());
        return tpAreaBasicPriceMapper.insertTpAreaBasicPrice(tpAreaBasicPrice);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param tpAreaBasicPrice 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTpAreaBasicPrice(TpAreaBasicPrice tpAreaBasicPrice) {
        tpAreaBasicPrice.setUpdateTime(DateUtils.getNowDate());
        return tpAreaBasicPriceMapper.updateTpAreaBasicPrice(tpAreaBasicPrice);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTpAreaBasicPriceByIds(Long[] ids) {
        return tpAreaBasicPriceMapper.deleteTpAreaBasicPriceByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTpAreaBasicPriceById(Long id) {
        return tpAreaBasicPriceMapper.deleteTpAreaBasicPriceById(id);
    }
}
