package com.ruoyi.project.business.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.business.domain.TpAreaBasicPrice;
import com.ruoyi.project.business.service.ITpAreaBasicPriceService;
import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2024-05-20
 */
@RestController
@RequestMapping("/business/price")
public class TpAreaBasicPriceController extends BaseController {

    @Resource
    private ITpAreaBasicPriceService tpAreaBasicPriceService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('business:price:list')")
    @GetMapping("/list")
    public TableDataInfo list(TpAreaBasicPrice tpAreaBasicPrice) {
        startPage();
        List<TpAreaBasicPrice> list = tpAreaBasicPriceService.selectTpAreaBasicPriceList(tpAreaBasicPrice);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('business:price:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TpAreaBasicPrice tpAreaBasicPrice) {
        List<TpAreaBasicPrice> list = tpAreaBasicPriceService.selectTpAreaBasicPriceList(tpAreaBasicPrice);
        ExcelUtil<TpAreaBasicPrice> util = new ExcelUtil<TpAreaBasicPrice>(TpAreaBasicPrice.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:price:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tpAreaBasicPriceService.selectTpAreaBasicPriceById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('business:price:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TpAreaBasicPrice tpAreaBasicPrice) {
        return toAjax(tpAreaBasicPriceService.insertTpAreaBasicPrice(tpAreaBasicPrice));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('business:price:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TpAreaBasicPrice tpAreaBasicPrice) {
        return toAjax(tpAreaBasicPriceService.updateTpAreaBasicPrice(tpAreaBasicPrice));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('business:price:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tpAreaBasicPriceService.deleteTpAreaBasicPriceByIds(ids));
    }
}
